==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/link/lang/af.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'af', {
	acccessKey: 'Toegangsleutel',
	advanced: 'Gevorderd',
	advisoryContentType: 'Aanbevole inhoudstipe',
	advisoryTitle: 'Aanbevole titel',
	anchor: {
		toolbar: 'Anker byvoeg/verander',
		menu: 'Anker-eienskappe',
		title: 'Anker-eienskappe',
		name: 'Ankernaam',
		errorName: 'Voltooi die ankernaam asseblief',
		remove: 'Remove Anchor'
	},
	anchorId: 'Op element Id',
	anchorName: 'Op ankernaam',
	charset: 'Karakterstel van geskakelde bron',
	cssClasses: 'CSS klasse',
	emailAddress: 'E-posadres',
	emailBody: 'Berig-inhoud',
	emailSubject: 'Berig-onderwerp',
	id: 'Id',
	info: 'Skakel informasie',
	langCode: 'Taalkode',
	langDir: 'Skryfrigting',
	langDirLTR: 'Links na regs (LTR)',
	langDirRTL: 'Regs na links (RTL)',
	menu: 'Wysig skakel',
	name: 'Naam',
	noAnchors: '(Geen ankers beskikbaar in dokument)',
	noEmail: 'Gee die e-posadres',
	noUrl: 'Gee die skakel se URL',
	other: '<ander>',
	popupDependent: 'Afhanklik (Netscape)',
	popupFeatures: 'Eienskappe van opspringvenster',
	popupFullScreen: 'Volskerm (IE)',
	popupLeft: 'Posisie links',
	popupLocationBar: 'Adresbalk',
	popupMenuBar: 'Spyskaartbalk',
	popupResizable: 'Herskaalbaar',
	popupScrollBars: 'Skuifbalke',
	popupStatusBar: 'Statusbalk',
	popupToolbar: 'Werkbalk',
	popupTop: 'Posisie bo',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Kies \'n anker',
	styles: 'Styl',
	tabIndex: 'Tab indeks',
	target: 'Doel',
	targetFrame: '<raam>',
	targetFrameName: 'Naam van doelraam',
	targetPopup: '<opspringvenster>',
	targetPopupName: 'Naam van opspringvenster',
	title: 'Skakel',
	toAnchor: 'Anker in bladsy',
	toEmail: 'E-pos',
	toUrl: 'URL',
	toolbar: 'Skakel invoeg/wysig',
	type: 'Skakelsoort',
	unlink: 'Verwyder skakel',
	upload: 'Oplaai'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/link/lang/af.js <==
﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'af', {
	acccessKey: 'Toegangsleutel',
	advanced: 'Gevorderd',
	advisoryContentType: 'Aanbevole inhoudstipe',
	advisoryTitle: 'Aanbevole titel',
	anchor: {
		toolbar: 'Anker byvoeg/verander',
		menu: 'Anker-eienskappe',
		title: 'Anker-eienskappe',
		name: 'Ankernaam',
		errorName: 'Voltooi die ankernaam asseblief',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Remove Anchor'
	},
	anchorId: 'Op element Id',
	anchorName: 'Op ankernaam',
	charset: 'Karakterstel van geskakelde bron',
	cssClasses: 'CSS klasse',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-posadres',
	emailBody: 'Berig-inhoud',
	emailSubject: 'Berig-onderwerp',
	id: 'Id',
	info: 'Skakel informasie',
	langCode: 'Taalkode',
	langDir: 'Skryfrigting',
	langDirLTR: 'Links na regs (LTR)',
	langDirRTL: 'Regs na links (RTL)',
	menu: 'Wysig skakel',
	name: 'Naam',
	noAnchors: '(Geen ankers beskikbaar in dokument)',
	noEmail: 'Gee die e-posadres',
	noUrl: 'Gee die skakel se URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<ander>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Afhanklik (Netscape)',
	popupFeatures: 'Eienskappe van opspringvenster',
	popupFullScreen: 'Volskerm (IE)',
	popupLeft: 'Posisie links',
	popupLocationBar: 'Adresbalk',
	popupMenuBar: 'Spyskaartbalk',
	popupResizable: 'Herskaalbaar',
	popupScrollBars: 'Skuifbalke',
	popupStatusBar: 'Statusbalk',
	popupToolbar: 'Werkbalk',
	popupTop: 'Posisie bo',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Kies \'n anker',
	styles: 'Styl',
	tabIndex: 'Tab indeks',
	target: 'Doel',
	targetFrame: '<raam>',
	targetFrameName: 'Naam van doelraam',
	targetPopup: '<opspringvenster>',
	targetPopupName: 'Naam van opspringvenster',
	title: 'Skakel',
	toAnchor: 'Anker in bladsy',
	toEmail: 'E-pos',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Skakel invoeg/wysig',
	type: 'Skakelsoort',
	unlink: 'Verwyder skakel',
	upload: 'Oplaai'
} );
